function res=gamma_size(r,alfa,rn);
% gamma size distribution normalized to 1 
%input : 
%       r - radius
%       alfa - paramterer
%       rn - parameter
%
res=1./gamma(alfa).*(r./rn).^(alfa-1).*exp(-r./rn)./rn;